@@ -37,6 +37,8 @@ class FrameworkPipeline(Transformer):  # type: ignore
                     logger.info(
                         f"---- Running transformer {stage_name}  ({i} of {count_of_transformers}) ----"
                     )
+                else:
+                    stage_name = transformer.__class__.__name__
                     # self.spark_session.sparkContext.setJobDescription(stage_name)
                     # print_memory_stats(sc(df))
                 with ProgressLogMetric(
@@ -48,6 +50,8 @@ class FrameworkPipeline(Transformer):  # type: ignore
                 if hasattr(transformer, "getName"):
                     # noinspection Mypy
                     stage_name = transformer.getName()
+                else:
+                    stage_name = transformer.__class__.__name__
                 logger.error(
                     f"!!!!!!!!!!!!! stage {stage_name} threw exception !!!!!!!!!!!!!"
                 )
@@ -55,7 +59,13 @@ class FrameworkPipeline(Transformer):  # type: ignore
                 friendly_spark_exception: FriendlySparkException = FriendlySparkException(
                     exception=e, stage_name=stage_name
                 )
-                logger.error(msg=friendly_spark_exception.message)
+                error_messages: List[
+                    str] = friendly_spark_exception.message.split(
+                        "\n"
+                    ) if friendly_spark_exception.message else []
+                for error_message in error_messages:
+                    logger.error(msg=error_message)
+
                 if hasattr(transformer, "getSql"):
                     # noinspection Mypy
                     logger.error(transformer.getSql())
